'use strict'
const meta = require('meta-ngin')
const winston = require('winston')
const util = require('./util')
const controllers = require('./config')
const config = controllers.retrieve

module.exports = function (req, res) {
  if (!controllers.configured()) throw new Error('The identity-code-api-controllers must be configured prior to a request. Please refer to the middleware section of this module.')
  if (!req.verifiedJWTs) throw new Error('In order for the Identity Code APIs to function properly, the byu-jwt module must be used. Please download and implement it now.')
  if (!req.verifiedJWTs.current) throw new Error('It appears there is no BYU ID included in the request. You might try updating your byu-jwt module.')

  winston.info('Creating new resource')

  util.getObjects()
    .then(data => {
      data.forEach((code_set, index, array) => {
        if (code_set[config.resourceNameSingular()] === req.body[config.resourceNameSingular()]) {
          if ((config.sortNameSingular() && code_set[config.sortNameSingular()] === req.body[config.sortNameSingular()]) ||
            !config.sortNameSingular()) {
            data.splice(index, 1)
          }
        }
      })
      return data
    })
    .then(data => {
      data.push(Object.assign(req.body, {
        updated_by_id: req.verifiedJWTs.current.byu.client.byuId,
        date_time_updated: (new Date()).toISOString()
      }))
      util.putObject(data)
      util.log(req, req.body, 'create')
    })
    .then(() => {
      if (controllers.raiseEvents()) {
        util.raiseEvent(Object.assign({
          log_action: `${controllers.retrieve.resourceNameSingular()}__create`,
          updated_by_id: req.verifiedJWTs.current.byu.client.byuId,
          date_time_updated: new Date().toISOString()
        }, req.body))
      }
      let response = util.formatRes(req.body, 201)
      res.status(201).send(response)
    })
    .catch(err => {
      console.error(err)
      res.status(500).send({metadata: meta(500, err.message)})
    })
}
