'use strict'
const meta = require('meta-ngin')
const winston = require('winston')
const util = require('./util')
const controllers = require('./config')
const config = controllers.retrieve

module.exports = function (req, res) {
  if (!controllers.configured()) throw new Error('The identity-code-api-controllers must be configured prior to a request. Please refer to the middleware section of this module.')
  winston.info('Getting all resources')
  util.getObjects()
    .then(s3 => {
      let query = {}
      let queries = Object.keys(req.query)
      if (queries.length > 0) {
        for (let i = 0; i < queries.length; i++) {
          if (queries[i] !== 'page_start' && queries[i] !== 'page_size') {
            query = Object.assign(query, {
              [queries[i]]: req.query[queries[i]]
            })
          }
        }
      }
      if (controllers.paginate()) {
        query = Object.assign(query, {
          page_start: (req.query.page_start ? req.query.page_start : config.pageDefaultStart()),
          page_size: (req.query.page_size ? req.query.page_size : config.pageDefaultSize())
        })
      }
      let response = util.formatCollectionRes(s3, null, false, query)
      res.status(200).send(response)
    })
    .catch(err => {
      console.error(err)
      res.status(500).send({metadata: meta(500, err.message)})
    })
}
