'use strict'
const meta = require('meta-ngin')
const winston = require('winston')
const util = require('./util')
const controllers = require('./config')
const config = controllers.retrieve

module.exports = function (req, res) {
  if (!controllers.configured) throw new Error('The identity-code-api-controllers must be configured prior to a request. Please refer to the middleware section of this module.')
  winston.info('Retrieving resource logs')
  util.getObjects(true)
    .then(data => util.getObject(data, req.params[config.resourceNameSingular()], req.params[config.sortNameSingular()]))
    .then(code_logs => {
      let page = {}
      if (controllers.paginate()) {
        page = {
          page_start: (req.query.page_start ? req.query.page_start : config.pageDefaultStart()),
          page_size: (req.query.page_size ? req.query.page_size : config.pageDefaultSize())
        }
      }

      let response = util.formatCollectionRes(code_logs, null, true, page)
      res.status(200).send(response)
    })
    .catch(err => {
      console.error(err)
      if (err.message === 'Resource not found') res.status(404).send({metadata: meta(404, err.message)})
      else res.status(500).send({metadata: meta(500, err.message)})
    })
}
