'use strict'
const meta = require('meta-ngin')
const winston = require('winston')
const util = require('./util')
const controllers = require('./config')
const config = controllers.retrieve

module.exports = function (req, res) {
  if (!controllers.configured()) throw new Error('The identity-code-api-controllers must be configured prior to a request. Please refer to the middleware section of this module.')
  if (!req.verifiedJWTs) throw new Error('In order for the Identity Code APIs to function properly, the byu-jwt module must be used. Please download and implement it now.')
  if (!req.verifiedJWTs.current) throw new Error('It appears there is no BYU ID included in the request. You might try updating your byu-jwt module.')

  winston.info('Modifying a resource')
  util.getObjects()
    .then(data => {
      let removed = []
      data.forEach((code_set, index, array) => {
        if (code_set[config.resourceNameSingular()] === req.params[config.resourceNameSingular()]) {
          if ((config.sortNameSingular() && code_set[config.sortNameSingular()] === req.body[config.sortNameSingular()]) ||
            !config.sortNameSingular()) {
            removed = array.splice(index, 1)
          }
        }
      })
      if (removed.length > 0) {
        data.push(Object.assign(req.body, {
          updated_by_id: req.verifiedJWTs.current.byu.client.byuId,
          date_time_updated: (new Date()).toISOString()
        }))
        util.putObject(data)
        util.log(req, req.body, 'modify')
      } else throw new Error('Resource not found')
    })
    .then(() => {
      if (controllers.raiseEvents()) {
        util.raiseEvent(Object.assign({
          log_action: `${config.resourceNameSingular()}__modify`,
          updated_by_id: req.verifiedJWTs.current.byu.client.byuId,
          date_time_updated: new Date().toISOString()
        }, req.body))
      }
      let response = util.formatRes(req.body)
      res.status(200).send(response)
    })
    .catch(err => {
      console.error(err)
      if (err.message === 'Resource not found') res.status(404).send({metadata: meta(404, err.message)})
      else res.status(500).send({metadata: meta(500, err.message)})
    })
}
